# _abstract_incremental_archiver.py
#
# Project: AutoArchive
# License: GNU GPLv3
#
# Copyright (C) 2003 - 2012 Róbert Čerňanský



""":class:`_AbstractIncrementalArchiver` class."""



__all__ = ["_AbstractIncrementalArchiver"]



# {{{ INCLUDES

from abc import *

from .. import *
from ._abstract_archiver import *

# }}} INCLUDES



# {{{ CLASSES

class _AbstractIncrementalArchiver(_AbstractArchiver):
    """An archiver that supports incremental archiving.

    Abstract constructor of this class, should be called from derived constructors.

    :param interfaceAccessor: An :class:`.IInterfaceAccessor` instance.
    :type interfaceAccessor: :class:`.IInterfaceAccessor`"""



    @abstractmethod
    def __init__(self, interfaceAccessor):
        super().__init__(interfaceAccessor)



    @abstractproperty
    def nextBackupLevel(self):
        """Gets a next :term:`backup level` (starting from 0) that would be created.

        See also: :attr:`restartReason`.

        :rtype: ``int``"""



    @abstractproperty
    def restartReason(self):
        """Gets a :term:`backup level` restart reason.

        See also: :attr:`nextBackupLevel`.

        :rtype: ``BackupLevelRestartReasons``"""



    @abstractproperty
    def restartLevel(self):
        """Gets the :term:`backup level` to which would be restarted.

        Restart backup level is determined based on the backup file size.  Full restart is not taken into
        account; the returned value will always be > 0.

        :rtype: ``int``"""



    @abstractmethod
    def getMaxBackupLevel(self):
        """Returns maximal :term:`backup level` that can be created.

        Maximal backup level is the current backup level + 1.  If 0 is returned it means that
        the backup was never created yet or it was created as non-incremental.

        See also: :meth:`getBackupLevelForArchive()`

        :return: Maximal :term:`backup level` that can be created starting from 0.
        :rtype: ``int``"""



    @classmethod
    @abstractmethod
    def getBackupLevelForArchive(cls, archiveName, userConfigDir):
        """Returns the current backup level for the archive named ``archiveName``.

        :param archiveName: Name of the archive which backup level shall be determined.
        :type archiveName: ``str``
        :param userConfigDir: User configuration directory.
        :type userConfigDir: ``str``

        :return: Backup level or ``None``.
        :rtype: ``int``"""

# }}} CLASSES
